@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -455,6 +455,9 @@ public:
 
     const char *getHeader(size_t index) const
     {
+        if (index >= HttpHeader::H_HEADER_END)
+            return NULL;
+
         int offset = (index < HttpHeader::H_TE ?
                          m_commonHeaderOffset[index] :
                          m_otherHeaderOffset[index - HttpHeader::H_TE]);
@@ -476,6 +479,8 @@ public:
     {   return m_commonHeaderOffset[index];     }
     int getHeaderLen(size_t index) const
     {
+        if (index >= HttpHeader::H_HEADER_END)
+            return 0;
         return (index < HttpHeader::H_TE ?
                  m_commonHeaderLen[ index ] :
                  m_otherHeaderLen[ index - HttpHeader::H_TE]);
