@@ -52,6 +52,19 @@ class UrlVary;
 #define CIF_PRIV_TRACK_HASH 16
 #define CIF_STALE_PURGE     32
 
+#define CM_TRACK_LITEMAGE 1
+#define CM_TRACK_PRIVATE  2
+
+typedef struct shm_objtrack_s
+{
+    uint32_t    x_tmCreated;
+    uint32_t    x_tmExpire;
+    uint8_t     x_flag;
+    uint8_t     x_hits;
+    uint8_t     x_reserve[2];
+}shm_objtrack_t;
+
+
 typedef struct purgeinfo_s
 {
     int32_t     tmSecs;
@@ -85,7 +98,7 @@ public:
     {
         memset(m_stats, 0, (char *)&m_tmLastHouseKeeping - (char*)m_stats);
     }
-    
+
     int32_t getNextPrivateTagId()
     {   return ls_atomic_fetch_add(&m_iCurPrivateTagId, 1) + 1;    }
 
@@ -140,6 +153,8 @@ public:
     {   return m_iSessionPurged - m_iLastCleanSessPurge;    }
 
     uint32_t getFlags() const       {   return m_iFlags;        }
+    void     setFlags(uint32_t f)   {   m_iFlags = f;        }
+    
     void updateFlag(uint32_t f, uint32_t val)
     {
         uint32_t old;
@@ -154,7 +169,7 @@ public:
         }
         while(!ls_atomic_cas32(&m_iFlags, old, new_val));
     }
-    
+
 private:
     int32_t     m_tmPurgeSecs;
     int32_t     m_tmPurgeMsecs;
@@ -199,10 +214,10 @@ public:
     virtual int isPurged(CacheEntry *pEntry, CacheKey *pKey,
                          bool isCheckPrivate) = 0;
     virtual int processPurgeCmd(const char *pValue, int iValLen,
-                                time_t curTime, int curTimeMS) = 0;
+                                time_t curTime, int curTimeMS, int stale) = 0;
     virtual int processPrivatePurgeCmd(
         CacheKey *pKey, const char *pValue, int iValLen,
-        time_t curTime, int curTimeMS) = 0;
+        time_t curTime, int curTimeMS, int stale) = 0;
 
     virtual int addUrlVary(const char *pUrl, int len, int32_t id) = 0;
 
@@ -234,6 +249,18 @@ public:
 
     virtual int houseKeeping() = 0;
     virtual int shouldCleanDiskCache() = 0;
+      
+    
+    void updateStatsExpireByTracking(shm_objtrack_t* pData);
+    
+    
+    virtual int  addTracking(CacheEntry * pEntry) = 0;
+    virtual int  removeTracking(const char *pKey, int keyLen, int isPrivate) = 0;
+    virtual int  trimExpiredByTracking(int isPrivate, int maxCnt, 
+                                       int (*removeEntry)(void *, void *), 
+                                       void *param) = 0;
+    virtual int  isInTracker(const unsigned char* getKey, int keyLen, 
+                             int isPrivate) = 0;
 
 private:
     virtual CacheInfo *getCacheInfo() = 0;
