@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -51,8 +51,7 @@ public:
                                       int32_t lastCacheFlush) = 0;
 
     virtual CacheEntry *createCacheEntry(const CacheHash &hash,
-                                         CacheKey *pKey,
-                                         int force) = 0;
+                                         CacheKey *pKey) = 0;
 
 //    virtual CacheEntry * getCacheEntry( const char * pKey, int keyLen ) = 0;
 
@@ -87,8 +86,8 @@ public:
     }
 
 
-    void addToDirtyList(CacheEntry *pEntry)
-    {   m_dirtyList.push_back(pEntry);        }
+    int addToHash(CacheEntry *pEntry);
+    void addToDirtyList(CacheEntry *pEntry);
 
     CacheManager *getManager()   {   return m_pManager;    }
 
@@ -104,7 +103,15 @@ public:
 //         return m_iMaxObjSize;
 //     }
 
+    int getCacheDirPath(char *pBuf, int len,
+        const unsigned char *pHashKey, int isPrivate);
     void debug_dump(CacheEntry *pEntry, const char *msg);
+    
+    int cleanByTracking(int public_max, int private_max);
+    
+    static int cleanByTrackingCb(void *, void *);
+    
+    virtual void removeEntryByHash(const unsigned char * pKey, int keyLen) = 0;
 
 protected:
     virtual int renameDiskEntry(CacheEntry *pEntry, char *pFrom, size_t maxFrom,
